aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Entities/CategoryInfo.cs
diff options
context:
space:
mode:
Diffstat (limited to 'MediaBrowser.Model/Entities/CategoryInfo.cs')
-rw-r--r--MediaBrowser.Model/Entities/CategoryInfo.cs10
1 files changed, 4 insertions, 6 deletions
diff --git a/MediaBrowser.Model/Entities/CategoryInfo.cs b/MediaBrowser.Model/Entities/CategoryInfo.cs
index adf8ac7d96..934a0ae1d1 100644
--- a/MediaBrowser.Model/Entities/CategoryInfo.cs
+++ b/MediaBrowser.Model/Entities/CategoryInfo.cs
@@ -2,16 +2,14 @@
namespace MediaBrowser.Model.Entities
{
/// <summary>
/// This is a stub class used by the api to get IBN types in a compact format
/// </summary>
- public class CategoryInfo
+ public class CategoryInfo<T>
{
/// <summary>
- /// The name of the genre, year, studio, etc
+ /// The actual genre, year, studio, etc
/// </summary>
- public string Name { get; set; }
-
- public string PrimaryImagePath { get; set; }
+ public T Item { get; set; }
/// <summary>
/// The number of items that have the genre, year, studio, etc
@@ -2,16 +2,14 @@
{
/// <summary>
- /// This is a stub class used by the api to get IBN types in a compact format
+ /// This is a stub class used by the api to get IBN types along with their item counts
/// </summary>